#!/usr/bin/env python
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Common implementation for all hooks.
"""

import jujuresources


def bootstrap_resources():
    """
    Install required resources defined in resources.yaml
    """
    mirror_url = jujuresources.config_get('resources_mirror')
    if not jujuresources.fetch(mirror_url=mirror_url):
        jujuresources.juju_log('Resources unavailable; manual intervention required', 'ERROR')
        return False
    jujuresources.install(['pathlib', 'pyaml', 'six', 'charmhelpers', 'jujubigdata'])
    return True


def manage():
    if not bootstrap_resources():
        # defer until resources are available, since charmhelpers, and thus
        # the framework, are required (will require manual intervention)
        return

    from charmhelpers.core import charmframework
    import jujubigdata
    import callbacks

    hive_reqs = ['vendor', 'hadoop_version', 'packages', 'groups', 'users',
                 'dirs', 'ports']
    dist_config = jujubigdata.utils.DistConfig(filename='dist.yaml',
                                               required_keys=hive_reqs)
    hive = callbacks.Hive(dist_config)
    manager = charmframework.Manager([
        {
            'name': 'hive',
            'provides': [
                jujubigdata.relations.Hive(port=dist_config.port('hive')),
            ],
            'requires': [
                jujubigdata.relations.HadoopPlugin(),
                jujubigdata.relations.MySQL(),
            ],
            'callbacks': [
                hive.install,
                hive.start,
            ],
            'cleanup': [
                hive.stop,
                hive.cleanup,
            ],
        },
    ])
    manager.manage()


if __name__ == '__main__':
    manage()
